(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     32189,        779]
NotebookOptionsPosition[     30922,        752]
NotebookOutlinePosition[     31319,        768]
CellTagsIndexPosition[     31276,        765]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 19 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"3c46f89a-80fc-4941-9825-bc1f056c167f"],

Cell[CellGroupData[{

Cell["Chapter 3, Section 3.9", "Section",
 CellChangeTimes->{
  3.857285322684043*^9},ExpressionUUID->"d125afea-f9cd-43e2-a90f-\
c4f85c545fa3"],

Cell["\<\
Here we develop an interactive tool for visualising orbits in the rotating \
frame for the circular restricted three-body problem.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.857285396497568*^9, 3.8572854418864183`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"871f09ee-5a89-4dcc-9f99-37c45a31e120"],

Cell[TextData[{
 "First we define a function, ",
 StyleBox["LagFind",
  FontWeight->"Bold"],
 ", to determine the locations of the five Lagrange points for a given value \
of the mass \[Mu]."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.857285396497568*^9, 3.857285543660375*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b65e0a4f-6321-49b4-a058-0370b29425d0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"LagFind", "[", "\[Mu]_", "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "r1", ",", "r2", ",", "L1", ",", "L2", ",", "L3", ",", "L4", ",", "L5", 
      ",", "\[IndentingNewLine]", 
      RowBox[{"\[Alpha]", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]", "/", 
          RowBox[{"(", 
           RowBox[{"3", "*", 
            RowBox[{"(", 
             RowBox[{"1", "-", "\[Mu]"}], ")"}]}], ")"}]}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "3"}], ")"}]}]}], ",", 
      RowBox[{"\[Beta]", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"7", "/", "12"}], ")"}]}], "*", 
         RowBox[{"(", 
          RowBox[{"\[Mu]", "/", 
           RowBox[{"(", 
            RowBox[{"1", "-", "\[Mu]"}], ")"}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"7", "/", "12"}], ")"}], "*", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Mu]", "/", 
            RowBox[{"(", 
             RowBox[{"1", "-", "\[Mu]"}], ")"}]}], ")"}], "^", "2"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"13223", "/", "20736"}], ")"}], "*", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Mu]", "/", 
            RowBox[{"(", 
             RowBox[{"1", "-", "\[Mu]"}], ")"}]}], ")"}], "^", "3"}]}]}]}]}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"L1", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "-", "\[Mu]", "-", 
         RowBox[{"(", 
          RowBox[{"r2", "/.", "\[IndentingNewLine]", 
           RowBox[{"FindRoot", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "\[Mu]"}], ")"}], "*", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "1"}], "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", "r2"}], ")"}], "^", "2"}]}], "+", "1", 
                  "-", "r2"}], ")"}]}], "-", 
               RowBox[{"\[Mu]", "*", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "1"}], "/", 
                   RowBox[{"r2", "^", "2"}]}], "+", "r2"}], ")"}]}]}], "==", 
              "0"}], ",", 
             RowBox[{"{", 
              RowBox[{"r2", ",", "\[Alpha]"}], "}"}]}], "]"}]}], ")"}]}], ",",
         "0"}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"L2", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "-", "\[Mu]", "+", 
         RowBox[{"(", 
          RowBox[{"r2", "/.", "\[IndentingNewLine]", 
           RowBox[{"FindRoot", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "\[Mu]"}], ")"}], "*", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "1"}], "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "+", "r2"}], ")"}], "^", "2"}]}], "+", "1", 
                  "+", "r2"}], ")"}]}], "+", 
               RowBox[{"\[Mu]", "*", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "1"}], "/", 
                   RowBox[{"r2", "^", "2"}]}], "+", "r2"}], ")"}]}]}], "==", 
              "0"}], ",", 
             RowBox[{"{", 
              RowBox[{"r2", ",", "\[Alpha]"}], "}"}]}], "]"}]}], ")"}]}], ",",
         "0"}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"L3", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[Mu]"}], "-", 
         RowBox[{"(", 
          RowBox[{"r1", "/.", "\[IndentingNewLine]", 
           RowBox[{"FindRoot", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "\[Mu]"}], ")"}], "*", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "1"}], "/", 
                   RowBox[{"r1", "^", "2"}]}], "+", "r1"}], ")"}]}], "+", 
               RowBox[{"\[Mu]", "*", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "1"}], "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "+", "r1"}], ")"}], "^", "2"}]}], "+", "1", 
                  "+", "r1"}], ")"}]}]}], "==", "0"}], ",", 
             RowBox[{"{", 
              RowBox[{"r1", ",", 
               RowBox[{"1", "+", "\[Beta]"}]}], "}"}]}], "]"}]}], ")"}]}], 
        ",", "0"}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"L4", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"0.5", "-", "\[Mu]"}], ",", 
        RowBox[{
         RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"L5", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"0.5", "-", "\[Mu]"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Sqrt", "[", "3", "]"}]}], "/", "2"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"L1", ",", "L2", ",", "L3", ",", "L4", ",", "L5"}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.855478187690501*^9, 3.855478312010507*^9}, {
   3.855478378175737*^9, 3.855478469585854*^9}, {3.85547850813591*^9, 
   3.8554785222565613`*^9}, {3.855478554441102*^9, 3.855478598512735*^9}, {
   3.855478632261034*^9, 3.855478646301046*^9}, {3.8554786878212633`*^9, 
   3.8554787628363857`*^9}, {3.8554787949828053`*^9, 
   3.8554788551012487`*^9}, {3.855479274427092*^9, 3.855479395597623*^9}, {
   3.855480511995549*^9, 3.855480514123427*^9}, {3.85548062481107*^9, 
   3.855480626145108*^9}, 3.855576238824217*^9},
 CellLabel->"In[1]:=",ExpressionUUID->"e0db743e-909a-462a-a70e-3cddbdbd5722"],

Cell[TextData[{
 "Now we define a function, ",
 StyleBox["ThreeBodyOrbit2Dziv",
  FontWeight->"Bold"],
 ", to solve the three-body problem for a given initial position, ",
 StyleBox["(x0,y0)",
  FontWeight->"Bold"],
 ", taking the initial velocity in the rotating frame to be zero. The \
quantity ",
 StyleBox["tmax",
  FontWeight->"Bold"],
 " is the number of orbital periods over which the numerical integration \
takes place and ",
 StyleBox["muval",
  FontWeight->"Bold"],
 " is the value of the mass \[Mu]."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.857285396497568*^9, 3.857285775737917*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"292a9aab-7ee6-4eb6-bbb1-02b453527d00"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ThreeBodyOrbit2Dziv", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x0_", ",", " ", "y0_"}], "}"}], ",", " ", "muval_", ",", " ", 
    "tmax_", ",", " ", "\n", "                ", 
    RowBox[{"ppoints_", ":", "100"}], ",", " ", 
    RowBox[{"maxsteps_", ":", "\[Infinity]"}]}], "]"}], " ", ":=", "\n", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"sol", ",", 
      RowBox[{"\[Mu]1", "=", 
       RowBox[{"1", "-", "muval"}]}], ",", 
      RowBox[{"\[Mu]2", "=", "muval"}]}], "}"}], ",", "\n", "  ", 
    RowBox[{
     RowBox[{"sol", " ", "=", " ", 
      RowBox[{"NDSolve", "[", "\n", "  ", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"x", "''"}], "[", "t", "]"}], "-", 
            RowBox[{"2", "*", 
             RowBox[{
              RowBox[{"y", "'"}], "[", "t", "]"}]}]}], " ", "==", "  ", "\n", 
           " ", 
           RowBox[{
            RowBox[{"x", "[", "t", "]"}], " ", "-", " ", 
            RowBox[{"\[Mu]1", "*", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"x", "[", "t", "]"}], "+", "\[Mu]2"}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Sqrt", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"x", "[", "t", "]"}], "+", "\[Mu]2"}], ")"}], "^",
                    "2"}], "+", 
                  RowBox[{
                   RowBox[{"y", "[", "t", "]"}], "^", "2"}]}], "]"}], "^", 
                "3"}], ")"}]}]}], " ", "-", "\n", "           ", 
            RowBox[{"\[Mu]2", "*", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"x", "[", "t", "]"}], "-", "\[Mu]1"}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Sqrt", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"x", "[", "t", "]"}], "-", "\[Mu]1"}], ")"}], "^",
                    "2"}], "+", 
                  RowBox[{
                   RowBox[{"y", "[", "t", "]"}], "^", "2"}]}], "]"}], "^", 
                "3"}], ")"}]}]}]}]}], ",", "\n", "   ", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "''"}], "[", "t", "]"}], "+", 
            RowBox[{"2", "*", 
             RowBox[{
              RowBox[{"x", "'"}], "[", "t", "]"}]}]}], " ", "==", " ", "\n", 
           "    ", 
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], " ", "-", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[Mu]1", "/", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Sqrt", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"x", "[", "t", "]"}], "+", "\[Mu]2"}], ")"}], "^",
                     "2"}], "+", 
                    RowBox[{
                    RowBox[{"y", "[", "t", "]"}], "^", "2"}]}], "]"}], "^", 
                  "3"}], ")"}]}], " ", "+", "\n", "            ", 
               RowBox[{"\[Mu]2", "/", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Sqrt", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"x", "[", "t", "]"}], "-", "\[Mu]1"}], ")"}], "^",
                     "2"}], "+", 
                    RowBox[{
                    RowBox[{"y", "[", "t", "]"}], "^", "2"}]}], "]"}], "^", 
                  "3"}], ")"}]}]}], ")"}], "*", 
             RowBox[{"y", "[", "t", "]"}]}]}]}], ",", "\n", "   ", 
          RowBox[{
           RowBox[{"x", "[", "0", "]"}], "==", "x0"}], ",", " ", 
          RowBox[{
           RowBox[{"y", "[", "0", "]"}], "==", "y0"}], ",", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"x", "'"}], "[", "0", "]"}], "==", "0"}], ",", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "'"}], "[", "0", "]"}], "==", "0"}]}], "}"}], ",", 
        "\n", "   ", 
        RowBox[{"{", 
         RowBox[{"x", ",", "y"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", 
          RowBox[{"tmax", "*", "2", "\[Pi]"}]}], "}"}], ",", " ", 
        RowBox[{"MaxSteps", "->", "maxsteps"}]}], "]"}]}], ";", "\n", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"x", "[", "t", "]"}], ",", 
            RowBox[{"y", "[", "t", "]"}]}], "}"}], "/.", "sol"}], "]"}], "[", 
        
        RowBox[{"[", "1", "]"}], "]"}], ",", "\n", "   ", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", 
         RowBox[{"tmax", "*", "2", "Pi"}], ",", "0.1"}], "}"}]}], "]"}]}]}], 
   "\n", "]"}]}]], "Input",
 CellChangeTimes->{{3.856857042239717*^9, 3.856857042242928*^9}, {
   3.856857074937725*^9, 3.8568570856073017`*^9}, {3.85685716467025*^9, 
   3.856857172333519*^9}, 3.856857260492271*^9, {3.8568576502525463`*^9, 
   3.8568576568227654`*^9}, {3.856857787326195*^9, 3.8568578578862457`*^9}, {
   3.856859236968474*^9, 3.856859237535432*^9}, {3.857019216653922*^9, 
   3.857019221416995*^9}, {3.857019283623665*^9, 3.8570192857669497`*^9}, {
   3.857019343411909*^9, 3.8570193450620403`*^9}, 3.857285790349885*^9},
 CellLabel->"In[2]:=",ExpressionUUID->"01bc2e77-6aef-45d5-8096-dab742f64531"],

Cell[TextData[{
 "Now we use the ",
 StyleBox["Manipulate",
  FontWeight->"Bold"],
 " function to set up an interactive window to show that paths in the \
rotating frame of the test particle in the planar, circular, restricted, \
three-body problem using the function ",
 StyleBox["ThreeBodyOrbit2Dziv",
  FontWeight->"Bold"],
 " to provide a numerical solution for initial values of ",
 StyleBox["(x0,y0)",
  FontWeight->"Bold"],
 " given in ",
 StyleBox["init",
  FontWeight->"Bold"],
 ".  By default the initial position for the first point is taken to be the \
L4 point.  The Lagrange points are denoted by red dots.\nClicking on an \
arbitrary point will start another integration from that point, deleting the \
previous plot.  The chosen point can also be dragged across the frame and the \
code will generate paths for all the intervening initial points \
interactively.  The code is based on versions of the Standard Map taken from \
the Wolfram Demonstrations website (e.g. \
https://demonstrations.wolfram.com/OrbitsOfTheChirikovStandardMap/ and \
https://demonstrations.wolfram.com/TheSawtoothStandardMap/).\n",
 StyleBox["N.B. The function ",
  FontSlant->"Italic"],
 StyleBox["ThreeBodyOrbit2Dziv",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[" can fail if the test particle gets too close to the secondary \
mass. In that case the frame will appear red but it will not necessarily \
crash the program.",
  FontSlant->"Italic"]
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.857285396497568*^9, 3.857285775737917*^9}, {
  3.857285818472279*^9, 3.857285981123189*^9}, {3.857286015818142*^9, 
  3.8572862279763803`*^9}, {3.8572862746564283`*^9, 3.857286402411068*^9}, {
  3.857286439820792*^9, 3.857286514313558*^9}, {3.8572865765731173`*^9, 
  3.857286607787616*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"8535c8eb-06bc-4cd7-9852-3ddbdb942f12"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"mpts", "=", "\[IndentingNewLine]", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"PointSize", "[", "0.05", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "mu"}], ",", "0"}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"PointSize", "[", 
           RowBox[{"0.1", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"mu", "/", 
                RowBox[{"(", 
                 RowBox[{"1", "-", "mu"}], ")"}]}], ")"}], "^", 
              RowBox[{"(", 
               RowBox[{"1", "/", "3"}], ")"}]}], ")"}]}], "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"1", "-", "mu"}], ",", "0"}], "}"}], "]"}]}], "}"}]}], 
       "}"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"pts", "=", 
     RowBox[{"LagFind", "[", "mu", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"lp", "=", 
     RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ThreeBodyOrbit2Dziv", "[", 
        RowBox[{"init", ",", "mu", ",", "n"}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"Joined", "->", "True"}], ",", 
       RowBox[{"FrameTicks", "\[Rule]", "None"}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"gpts", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"PointSize", "[", "0.01", "]"}], ",", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Point", "[", "#", "]"}], "&"}], ",", "pts"}], "]"}]}], 
       "}"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
     RowBox[{"mpts", ",", "gpts", ",", "lp", ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"Joined", "->", "True"}], ",", 
      RowBox[{"FrameTicks", "\[Rule]", "None"}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "20", ",", "\"\<orbital periods\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "10", ",", "20", ",", "50", ",", "100", ",", "200", ",", 
       "500", ",", "1000"}], "}"}], ",", "SetterBar"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"mu", ",", "0.0001", ",", "\"\<\[Mu]\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.01", ",", "0.001", ",", "0.0001", ",", "0.00001"}], "}"}], 
     ",", "SetterBar"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"init", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"0.5", "-", "mu"}], ",", 
         RowBox[{
          RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", "Automatic", ",", 
     RowBox[{"ControlType", "\[Rule]", "Locator"}], ",", 
     RowBox[{"LocatorAutoCreate", "\[Rule]", "True"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"AutorunSequencing", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "20"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "2"}], "}"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8568579443165617`*^9, 3.856857992690118*^9}, {
   3.856858027985859*^9, 3.856858107517982*^9}, {3.856858146112423*^9, 
   3.856858146472308*^9}, {3.856858183281933*^9, 3.856858201746882*^9}, 
   3.856858369088909*^9, {3.856858720615793*^9, 3.8568587345667257`*^9}, {
   3.856858774991539*^9, 3.85685881736707*^9}, 3.856858942504468*^9, {
   3.856859082883869*^9, 3.856859083573614*^9}, {3.856859193673642*^9, 
   3.856859198324471*^9}, {3.8568593391915092`*^9, 3.8568594011103153`*^9}, {
   3.856860050014687*^9, 3.8568600873292437`*^9}, {3.856860117598057*^9, 
   3.8568601247222853`*^9}, {3.856860481763111*^9, 3.856860570891367*^9}, {
   3.85686060750484*^9, 3.856860608165866*^9}, {3.85686064591922*^9, 
   3.8568606933334227`*^9}, 3.8568607290638113`*^9, {3.856860973463066*^9, 
   3.856860978465757*^9}, {3.856861051530189*^9, 3.856861131147975*^9}, {
   3.856862721207686*^9, 3.856862739731029*^9}, {3.856863101910322*^9, 
   3.856863196547063*^9}, {3.856863249976115*^9, 3.856863280966708*^9}, {
   3.8568633931229677`*^9, 3.8568634917326183`*^9}, {3.856863557913953*^9, 
   3.8568635585152197`*^9}, {3.856864541517346*^9, 3.8568645461526957`*^9}, {
   3.856864614598056*^9, 3.856864630468216*^9}, {3.856864854754757*^9, 
   3.856864888337627*^9}, {3.856865385975402*^9, 3.856865387148768*^9}, {
   3.856870931480953*^9, 3.8568710151503572`*^9}, {3.856871110537404*^9, 
   3.856871120210272*^9}, {3.85687117362712*^9, 3.856871178040574*^9}, {
   3.857019369797079*^9, 3.8570193765906*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"97bbf58f-6df0-4300-91b0-b44efc57a4be"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`init$$ = {
    0.4999, Rational[1, 2] 3^Rational[1, 2]}, $CellContext`mu$$ = 
    0.0001, $CellContext`n$$ = 20, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`n$$], 20, "orbital periods"}, {5, 10, 20, 50, 100, 
      200, 500, 1000}}, {{
       Hold[$CellContext`mu$$], 0.0001, "\[Mu]"}, {0.01, 0.001, 0.0001, 
      0.00001}}, {{
       Hold[$CellContext`init$$], {0.4999, Rational[1, 2] 3^Rational[1, 2]}}, 
      Automatic}}, Typeset`size$$ = {360., {178., 182.}}, Typeset`update$$ = 
    0, Typeset`initDone$$, Typeset`skipInitDone$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`init$$ = {
         0.5 - $CellContext`mu$$, Rational[1, 2] 
          3^Rational[1, 2]}, $CellContext`mu$$ = 0.0001, $CellContext`n$$ = 
        20}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> ($CellContext`mpts = Graphics[{{
            PointSize[0.05], 
            Point[{-$CellContext`mu$$, 0}]}, {
            PointSize[0.1 ($CellContext`mu$$/(1 - $CellContext`mu$$))^(1/3)], 
            
            
            Point[{1 - $CellContext`mu$$, 
              0}]}}]; $CellContext`pts = \
$CellContext`LagFind[$CellContext`mu$$]; $CellContext`lp = ListPlot[
          $CellContext`ThreeBodyOrbit2Dziv[$CellContext`init$$, \
$CellContext`mu$$, $CellContext`n$$], PlotRange -> {{-1.2, 1.2}, {-1.2, 1.2}},
           Frame -> True, Joined -> True, FrameTicks -> None, AspectRatio -> 
          Automatic]; $CellContext`gpts = Graphics[{Red, 
           PointSize[0.01], 
           Map[Point[#]& , $CellContext`pts]}]; 
       Show[$CellContext`mpts, $CellContext`gpts, $CellContext`lp, 
         PlotRange -> {{-1.2, 1.2}, {-1.2, 1.2}}, Frame -> True, Joined -> 
         True, FrameTicks -> None, AspectRatio -> Automatic]), 
      "Specifications" :> {{{$CellContext`n$$, 20, "orbital periods"}, {5, 10,
          20, 50, 100, 200, 500, 1000}, ControlType -> 
         SetterBar}, {{$CellContext`mu$$, 0.0001, "\[Mu]"}, {0.01, 0.001, 
         0.0001, 0.00001}, ControlType -> 
         SetterBar}, {{$CellContext`init$$, {
          0.5 - $CellContext`mu$$, Rational[1, 2] 3^Rational[1, 2]}}, 
         Automatic, ControlType -> Locator, LocatorAutoCreate -> True}}, 
      "Options" :> {AutorunSequencing -> {{1, 20}, {2, 6}, {3, 2}}}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{410., {237., 242.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`LagFind[
         Pattern[$CellContext`\[Mu], 
          Blank[]]] := 
       Module[{$CellContext`r1, $CellContext`r2, $CellContext`L1, \
$CellContext`L2, $CellContext`L3, $CellContext`L4, $CellContext`L5, \
$CellContext`\[Alpha] = ($CellContext`\[Mu]/(3 (1 - $CellContext`\[Mu])))^(1/
            3), $CellContext`\[Beta] = (-(7/12)) ($CellContext`\[Mu]/(
             1 - $CellContext`\[Mu])) + (7/
             12) ($CellContext`\[Mu]/(1 - $CellContext`\[Mu]))^2 - (13223/
            20736) ($CellContext`\[Mu]/(
             1 - $CellContext`\[Mu]))^3}, $CellContext`L1 = {
           1 - $CellContext`\[Mu] - ReplaceAll[$CellContext`r2, 
             
             FindRoot[(1 - $CellContext`\[Mu]) ((-1)/(1 - $CellContext`r2)^2 + 
                 1 - $CellContext`r2) - $CellContext`\[Mu] \
((-1)/$CellContext`r2^2 + $CellContext`r2) == 
              0, {$CellContext`r2, $CellContext`\[Alpha]}]], 
            0}; $CellContext`L2 = {
           1 - $CellContext`\[Mu] + ReplaceAll[$CellContext`r2, 
              
              FindRoot[(1 - $CellContext`\[Mu]) ((-1)/(1 + $CellContext`r2)^2 + 
                  1 + $CellContext`r2) + $CellContext`\[Mu] \
((-1)/$CellContext`r2^2 + $CellContext`r2) == 
               0, {$CellContext`r2, $CellContext`\[Alpha]}]], 
            0}; $CellContext`L3 = {-$CellContext`\[Mu] - 
            ReplaceAll[$CellContext`r1, 
             
             FindRoot[(
                
              1 - $CellContext`\[Mu]) ((-1)/$CellContext`r1^2 + \
$CellContext`r1) + $CellContext`\[Mu] ((-1)/(1 + $CellContext`r1)^2 + 
                 1 + $CellContext`r1) == 
              0, {$CellContext`r1, 1 + $CellContext`\[Beta]}]], 
            0}; $CellContext`L4 = {
           0.5 - $CellContext`\[Mu], Sqrt[3]/2}; $CellContext`L5 = {
           0.5 - $CellContext`\[Mu], (-Sqrt[3])/
            2}; {$CellContext`L1, $CellContext`L2, $CellContext`L3, \
$CellContext`L4, $CellContext`L5}], $CellContext`ThreeBodyOrbit2Dziv[{
          Pattern[$CellContext`x0, 
           Blank[]], 
          Pattern[$CellContext`y0, 
           Blank[]]}, 
         Pattern[$CellContext`muval, 
          Blank[]], 
         Pattern[$CellContext`tmax, 
          Blank[]], 
         Optional[
          Pattern[$CellContext`ppoints, 
           Blank[]], 100], 
         Optional[
          Pattern[$CellContext`maxsteps, 
           Blank[]], Infinity]] := 
       Module[{$CellContext`sol, $CellContext`\[Mu]1 = 
          1 - $CellContext`muval, $CellContext`\[Mu]2 = $CellContext`muval}, \
$CellContext`sol = 
          NDSolve[{
            Derivative[2][$CellContext`x][$CellContext`t] - 2 
              Derivative[
               1][$CellContext`y][$CellContext`t] == \
$CellContext`x[$CellContext`t] - $CellContext`\[Mu]1 \
(($CellContext`x[$CellContext`t] + $CellContext`\[Mu]2)/
               Sqrt[($CellContext`x[$CellContext`t] + $CellContext`\[Mu]2)^2 + \
$CellContext`y[$CellContext`t]^2]^3) - $CellContext`\[Mu]2 \
(($CellContext`x[$CellContext`t] - $CellContext`\[Mu]1)/
               Sqrt[($CellContext`x[$CellContext`t] - $CellContext`\[Mu]1)^2 + \
$CellContext`y[$CellContext`t]^2]^3), 
             Derivative[2][$CellContext`y][$CellContext`t] + 
              2 Derivative[
                1][$CellContext`x][$CellContext`t] == \
$CellContext`y[$CellContext`t] - ($CellContext`\[Mu]1/
                Sqrt[($CellContext`x[$CellContext`t] + $CellContext`\[Mu]2)^2 + \
$CellContext`y[$CellContext`t]^2]^3 + $CellContext`\[Mu]2/
                Sqrt[($CellContext`x[$CellContext`t] - $CellContext`\[Mu]1)^2 + \
$CellContext`y[$CellContext`t]^2]^3) $CellContext`y[$CellContext`t], \
$CellContext`x[0] == $CellContext`x0, $CellContext`y[0] == $CellContext`y0, 
             Derivative[1][$CellContext`x][0] == 0, 
             Derivative[1][$CellContext`y][0] == 
             0}, {$CellContext`x, $CellContext`y}, {$CellContext`t, 
             0, $CellContext`tmax 2 Pi}, MaxSteps -> $CellContext`maxsteps]; 
         Table[
           Part[
            Evaluate[
             ReplaceAll[{
               $CellContext`x[$CellContext`t], 
               $CellContext`y[$CellContext`t]}, $CellContext`sol]], 
            1], {$CellContext`t, 0, $CellContext`tmax 2 Pi, 0.1}]]}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.85686113220861*^9, 3.856861281064014*^9, 3.856861365216856*^9, {
   3.856862503592539*^9, 3.8568625087931023`*^9}, 3.856862742799428*^9, {
   3.856862785692371*^9, 3.856862787274798*^9}, {3.856863127162919*^9, 
   3.856863130658849*^9}, {3.856863496059651*^9, 3.8568635182737827`*^9}, 
   3.8568635612565813`*^9, {3.8568636234442463`*^9, 3.8568636253115*^9}, {
   3.856864623213909*^9, 3.856864639807917*^9}, {3.856864890053111*^9, 
   3.856864904947977*^9}, 3.856864963648038*^9, 3.8568651801751013`*^9, 
   3.856865388310048*^9, 3.856870722324258*^9, 3.8568709525406303`*^9, 
   3.856871016425967*^9, 3.8568711213970013`*^9, 3.85687117905161*^9, 
   3.8570192329576387`*^9, 3.8570192893624697`*^9, {3.857019349505856*^9, 
   3.857019377755348*^9}, 3.857020078940765*^9, 3.8572873214288673`*^9, 
   3.857287385321933*^9, 3.8909054046673403`*^9},
 CellLabel->"Out[3]=",ExpressionUUID->"40c74703-33f3-4c0a-8758-1928f5429bcc"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{948, 633},
WindowMargins->{{86, Automatic}, {Automatic, 33}},
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"78b6684f-3a87-4e9a-a1f4-a069506b3b02"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 387, 8, 53, "Text",ExpressionUUID->"3c46f89a-80fc-4941-9825-bc1f056c167f"],
Cell[CellGroupData[{
Cell[970, 32, 143, 3, 67, "Section",ExpressionUUID->"d125afea-f9cd-43e2-a90f-c4f85c545fa3"],
Cell[1116, 37, 332, 7, 53, "Text",ExpressionUUID->"871f09ee-5a89-4dcc-9f99-37c45a31e120"],
Cell[1451, 46, 379, 10, 53, "Text",ExpressionUUID->"b65e0a4f-6321-49b4-a058-0370b29425d0"],
Cell[1833, 58, 6201, 167, 304, "Input",ExpressionUUID->"e0db743e-909a-462a-a70e-3cddbdbd5722"],
Cell[8037, 227, 700, 20, 99, "Text",ExpressionUUID->"292a9aab-7ee6-4eb6-bbb1-02b453527d00"],
Cell[8740, 249, 5738, 145, 325, "Input",ExpressionUUID->"01bc2e77-6aef-45d5-8096-dab742f64531"],
Cell[14481, 396, 1889, 41, 283, "Text",ExpressionUUID->"8535c8eb-06bc-4cd7-9852-3ddbdb942f12"],
Cell[CellGroupData[{
Cell[16395, 441, 5975, 141, 388, "Input",ExpressionUUID->"97bbf58f-6df0-4300-91b0-b44efc57a4be"],
Cell[22373, 584, 8521, 164, 521, "Output",ExpressionUUID->"40c74703-33f3-4c0a-8758-1928f5429bcc"]
}, Open  ]]
}, Open  ]]
}
]
*)

